#include "console.h"
#include "sizes.h"

extern void error(std::string msg);
extern void error_ttf(std::string msg);

console::console(std::string filename) {
    this->font = TTF_OpenFont(filename.c_str(), CONSOLE_HEIGHT/2);
    if(this->font == NULL)
        error_ttf("Unable to open font");
    this->texture = NULL;
    this->dst.x = 10;
    this->dst.y = SCREEN_HEIGHT + 5;
    this->color.r = 255;
    this->color.g = 255;
    this->color.b = 255;
    this->color.a = 255;
}

console::~console() {
    if(this->texture != NULL) {
        SDL_DestroyTexture(this->texture);
    }
}

void console::set(SDL_Renderer * renderer, std::string text) {
    SDL_Surface * surface = TTF_RenderText_Solid(this->font, text.c_str(), this->color);
    if(surface == NULL)
        error_ttf("Unable to render text");
    this->dst.w = surface->w;
    this->dst.h = surface->h;
    this->dst.y = SCREEN_HEIGHT + CONSOLE_HEIGHT/2 - this->dst.h/2;
    this->texture = SDL_CreateTextureFromSurface(renderer, surface);
    if(this->texture == NULL)
        error("Unable to create texture from surface");
    SDL_FreeSurface(surface);
}

void console::draw(SDL_Renderer * renderer) {
    if(this->texture != NULL) {
        SDL_RenderCopy(renderer, this->texture, NULL, &this->dst);
    }
}
