#include "gauge.h"

gauge::gauge(unsigned int maximum) {
    this->maximum = maximum;
    this->value = 0;
}

bool gauge::is_full() {
    return(this->value >= this->maximum);
}

bool gauge::is_empty() {
    return(this->value <= 0);
}

unsigned int gauge::free_space() {
    return(this->maximum - this->value);
}

void gauge::increase(unsigned int value) {
    this->value = std::min(this->value + value, this->maximum);
}

void gauge::decrease(unsigned int value) {
    this->value = std::max(this->value - value, (unsigned)0);
}

void gauge::gather(struct gauge * gauge) {
    unsigned int transfert = std::min(this->free_space(), gauge->value);
    gauge->decrease(transfert);
    this->increase(transfert);
}

void gauge::draw_top(SDL_Renderer * renderer, struct unit * unit, struct sprite * sprite, unsigned int shift) {
    int w = unit->model->sprite.rect.w;
    int h = unit->model->sprite.rect.h;
    for(unsigned int i=0; i<this->value; i++) {
        sprite->draw(renderer,
                unit->x - w/2 + ((i+shift)%5)*sprite->rect.w,
                unit->y - h/2 + ((i+shift)/5)*sprite->rect.h);
    }
}

void gauge::draw_bot(SDL_Renderer * renderer, struct unit * unit, struct sprite * sprite, unsigned int shift) {
    int w = unit->model->sprite.rect.w;
    int h = unit->model->sprite.rect.h;
    for(unsigned int i=0; i<this->value; i++) {
        sprite->draw(renderer,
                unit->x - w/2 + ((i+shift)%5)*sprite->rect.w,
                unit->y + h/2 - ((i+shift)/5)*sprite->rect.h);
    }
}
