#include "morphing.h"
#include "square.h"

#define TEXTURE_SIZE 10

extern void error(std::string msg);

morphing::morphing(SDL_Renderer * renderer, unsigned int maximum, std::vector<std::string> filenames) :
    maximum(maximum),
    sprites(filenames.size())
{
    for(unsigned int i=0; i<filenames.size(); i++) {
        this->sprites.at(i) = new sprite(renderer, filenames.at(i));
        this->sprites.at(i)->rect.w = this->sprites.at(i)->rect.h = SQUARE_SIZE;
    }
}

morphing::morphing(SDL_Renderer * renderer, unsigned int maximum, std::string filename) :
    maximum(maximum)
{
    struct sprite * sprite_buffer;
    SDL_Surface * surface_source;
    SDL_Surface * surface_buffer;
    SDL_Rect src;

    src.w = src.h = TEXTURE_SIZE;
    src.y = 0;
    surface_source = SDL_LoadBMP(filename.c_str());
    if(surface_source == NULL)
        error("Unable to load bmp file");
    surface_buffer = SDL_CreateRGBSurface(0, TEXTURE_SIZE, TEXTURE_SIZE, 32, 0, 0, 0, 0);
    if(surface_buffer == NULL)
        error("Unable to create RGB surface");
    for(int shift=0; (shift+1)*TEXTURE_SIZE <= surface_source->w; shift++) {
        src.x = shift*TEXTURE_SIZE;
        SDL_BlitSurface(surface_source, &src, surface_buffer, NULL);
        sprite_buffer = new sprite(renderer, surface_buffer);
        sprite_buffer->rect.w = sprite_buffer->rect.h = SQUARE_SIZE;
        this->sprites.push_back(sprite_buffer);
    }
    SDL_FreeSurface(surface_source);
    SDL_FreeSurface(surface_buffer);
}

morphing::~morphing() {
    for(struct sprite * sprite : this->sprites) {
        delete(sprite);
    }
}

void morphing::draw(SDL_Renderer * renderer, float x, float y, unsigned int value) {
    struct sprite * sprite;
    if(value >= this->maximum) {
        sprite = this->sprites[this->sprites.size()-1];
    } else if(value == 0) {
        sprite = this->sprites[0];
    } else {
        unsigned int n = (value-1) * (this->sprites.size()-1) / (this->maximum-1) + 1;
        sprite = this->sprites.at(n);
    }
    sprite->draw(renderer, x, y);
}
