#ifndef UNIT_H
#define UNIT_H

#include "model.h"
#include "gauge.h"
#include "square.h"
#include "sizes.h"

#include <forward_list>

#define COLLECT_DISTANCE 20
#define ENERGY_GENERATOR_THRESHOLD 100000

enum struct automata_state {
    nothing,
    refuel,
    drop,
    mine,
    // go,
    // wander,
};

struct unit {
    struct model * model;
    float x;
    float y;
    struct gauge * energy;
    struct gauge * cristal;
    struct gauge * powergem;
    unsigned int energy_accumulator;
    float target_x;
    float target_y;
    enum automata_state state;

    unit(struct model * model, float x, float y);
    ~unit();
    void draw(SDL_Renderer * renderer);
    bool can_build(struct model * model);
    float distance();
    float distance(struct unit * unit);
    float distance(float x, float y);
    void set_position(float x, float y);
    void move(float dx, float dy, struct square grid[GRID_WIDTH][GRID_HEIGHT]);
    void move_toward(float x, float y, struct square grid[GRID_WIDTH][GRID_HEIGHT]);
    void mine(struct square grid[GRID_WIDTH][GRID_HEIGHT]);
    void build(struct model * model, float x, float y, std::forward_list<struct unit *> * units);
    void cycle(std::forward_list<struct unit *> * units, struct square grid[GRID_WIDTH][GRID_HEIGHT]);
    void generate_energy();
    void collect_cristal(std::forward_list<struct unit *> * units);
    void collect_energy(std::forward_list<struct unit *> * units);
    void collect_powergem(std::forward_list<struct unit *> * units);
    struct unit * nearest_unit(struct model * model, std::forward_list<struct unit *> * units);
    struct unit * nearest_unit(std::string model_name, std::forward_list<struct unit *> * units);
    bool nearest_cristal(struct square grid[GRID_WIDTH][GRID_HEIGHT]);
    void target_nearest_cristal(struct square grid[GRID_WIDTH][GRID_HEIGHT]);
    void target_nearest_energen(std::forward_list<struct unit *> * units);
    void target_nearest_builder(std::forward_list<struct unit *> * units);
    unsigned int count_surrounding_rock(struct square grid[GRID_WIDTH][GRID_HEIGHT]);
};

#endif // UNIT_H
